.. |build-status| image:: https://api.travis-ci.org/bendikro/PyDbLite.svg?branch=master
    :target: https://travis-ci.org/bendikro/PyDbLite

.. |docs| image:: https://readthedocs.org/projects/pydblite/badge/?version=latest
    :target: https://pydblite.readthedocs.org
    :alt: Documentation Status

.. |pypi| image:: http://img.shields.io/pypi/v/pydblite.png
    :alt: PYPI Package
    :target: https://pypi.python.org/pypi/PyDbLite
